/**
 * 광역자치단체 이름을 축약합니다.
 * 두글자(충남, 서울) 등을 2글자로 지역 구분으로 바꿉니다.
 * 바뀌는 지역명에 대해서는 Readme.md를 참조하여 주시기 바랍니다.
 * @param list 지역명을 담고 있는 리스트입니다. ex) ['충남', '충북']
 * @param allow3words 3글자 지역명을 허용할지를 결정합니다.
 */
export function shortProvinceName2(list: Array<string>, allow3words: boolean = false) {
  const temp = [];
  let jeonla = 0;
  let honam = false;
  let yeongnam = 0;
  let kyeongin = 0;
  let chungcheong = 0;
  let kyeongsang = 0;
  let hoseo = false;
  let buulgyeong = 0;
  let gyeonggi = false;
  const c = ['충북', '충남'];
  const j = ['전북', '전남'];
  const h = '광주';
  const s = '세종';
  const i = ['서울', '인천'];
  const k = ['경북', '경남'];
  const y = ['울산', '부산', '대구'];
  const b = ['부산', '울산', '경남'];
  const g = '경기';
  const KSHY = ['전북', '전남', '광주', '경북', '경남', '울산', '부산', '대구', '충북', '충남', '세종', '서울', '인천', '경기'];
  list.forEach(v => {
    if (c.includes(v)) chungcheong++;
    else if (j.includes(v)) jeonla++;
    else if (h === v) honam = true;
    else if (s === v) hoseo = true;
    else if (i.includes(v)) kyeongin++;
    else if (k.includes(v)) kyeongsang++;
    else if (y.includes(v)) yeongnam++;
    else if (g === v) gyeonggi = true;
    if (b.includes(v)) buulgyeong++;
  });
  honam = honam && jeonla === 2;
  hoseo = hoseo && chungcheong === 2;
  list.forEach(v => {
    if ((chungcheong === 1 && c.includes(v)) || (!hoseo && v === s) ||
      (jeonla === 1 && j.includes(v)) || (!honam && v === h) ||
      (kyeongsang === 1 && k.includes(v) && buulgyeong <= 2) || (kyeongsang === 1 && y.includes(v) && !b.includes(v)) || (buulgyeong <= 2 && kyeongsang === 1 && b.includes(v)) ||
      (kyeongin === 1 && i.includes(v)) || (kyeongin === 1 && v === g) ||
      !KSHY.includes(v)) temp.push(v);
  });
  if (kyeongin === 2 && gyeonggi) temp.push('수도권');
  else if (kyeongin === 2) temp.push("경인");
  if (chungcheong === 2 && !hoseo) temp.push('충청');
  if (chungcheong === 2 && hoseo) temp.push('호서');
  if (jeonla === 2 && !honam) temp.push("전라");
  if (honam) temp.push("호남");
  if (kyeongsang === 2 && yeongnam !== 3) temp.push("경상");
  if (kyeongsang === 1 && buulgyeong === 3 && allow3words) temp.push('부울경');
  if (kyeongsang === 2 && yeongnam === 3) temp.push("영남");
  return temp;
}

/**
 * 광역자치단체 이름을 축약합니다.
 * 두글자(충청남도, 서울특별시) 등을 2글자로 지역 구분으로 바꿉니다.
 * 바뀌는 지역명에 대해서는 Readme.md를 참조하여 주시기 바랍니다.
 * @param list 지역명을 담고 있는 리스트입니다. ex) ['충청남도', '충청북도']
 */
export function shortProvinceName(list: Array<string>) {
  const temp = [];
  let jeonla = 0;
  let honam = false;
  let yeongnam = 0;
  let kyeongin = 0;
  let chungcheong = 0;
  let kyeongsang = 0;
  let hoseo = false;
  let buulgyeong = 0;
  let gyeonggi = false;
  const c = ['충청북도', '충청남도'];
  const j = ['전라북도', '전라남도'];
  const h = '광주광역시';
  const s = '세종특별자치시';
  const i = ['서울특별시', '인천광역시'];
  const k = ['경상북도', '경상남도'];
  const y = ['울산광역시', '부산광역시', '대구광역시'];
  const b = ['부산광역시', '울산광역시', '경상남도'];
  const g = '경기도';
  const KSHY = ['전라북도', '전라남도', '광주광역시', '경상북도', '경상남도', '부산광역시', '대구광역시', '울산광역시', '충청북도', '충청남도', '세종특별자치시', '서울특별시', '인천광역시', '경기도'];
  list = list.map(v => v.trim());
  list.forEach(v => {
    if (c.includes(v)) chungcheong++;
    else if (j.includes(v)) jeonla++;
    else if (h === v) honam = true;
    else if (s === v) hoseo = true;
    else if (i.includes(v)) kyeongin++;
    else if (k.includes(v)) kyeongsang++;
    else if (y.includes(v)) yeongnam++;
    else if (g === v) gyeonggi = true;
    if (b.includes(v)) buulgyeong++;
  });
  honam = honam && jeonla === 2;
  hoseo = hoseo && chungcheong === 2;
  list.forEach(v => {
    if ((chungcheong === 1 && c.includes(v)) || (!hoseo && v === s) ||
      (jeonla === 1 && j.includes(v)) || (!honam && v === h) ||
      (kyeongsang === 1 && k.includes(v) && buulgyeong <= 2) || (kyeongsang === 1 && y.includes(v) && !b.includes(v)) || (buulgyeong <= 2 && kyeongsang === 1 && b.includes(v)) ||
      (kyeongin === 1 && i.includes(v)) || (kyeongin === 1 && v === g) ||
      !KSHY.includes(v)) temp.push(v);
  });
  if (kyeongin === 2 && gyeonggi) temp.push('수도권');
  else if (kyeongin === 2) temp.push("경인 지방");
  if (chungcheong === 2 && !hoseo) temp.push('충청도');
  if (chungcheong === 2 && hoseo) temp.push('호서 지방');
  if (jeonla === 2 && !honam) temp.push("전라도");
  if (honam) temp.push("호남 지방");
  if (kyeongsang === 2 && yeongnam !== 3) temp.push("경상도");
  if (kyeongsang === 1 && buulgyeong === 3) temp.push('부울경');
  if (kyeongsang === 2 && yeongnam === 3) temp.push("영남 지방");
  return temp;
}